# PythonPals

## Usage
`This project is a game intended to teach new programmers basic concepts of the Python language in an
engaging, 2D battle. Players will choose which concepts they would like to review (e.g. syntax, logic,
number conversion) and then enter a battle scene where they will be asked multiple-choice questions and
be expected to provide the correct answer. A correct answer deals damage to the opponent while an
incorrect answer reduces the player's own HP. The player wins when their opponent's HP reaches zero and
the player loses if their own HP reaches zero. The production release now also includes the option to change the 
questions to History and Geography categories as well as multiple levels and sound effects for feedback.

`**Note about bugs: Possible issue with pip installation in which relative file paths are not recognized.`

## Package name for PIP installation
May need to run as administrator on Windows from PythonPals-2.1.2
pip install . 


## Run executable command 
python-pals

To run from 
the .tgz file, cd into "PythonPals-VersionNumber", then cd into "Python Pals" and then run python main.py from the
present directory
## GitHub repository:
https://github.com/nathanhilton/PythonPals
